# -*- coding: utf-8 -*-
'''
Author: David A. Schulenberg
Email: schulenberg@aept.rub.de

This script is part of the research paper "Mode transition induced by gas heating along
the discharge channel in capacitively coupled atmospheric pressure micro plasma jets"

This script is licensed under the MIT License.
See the file "LICENSE.txt" for the full license text.
'''


import numpy as np
import matplotlib.pyplot as plt

plt.rcParams['font.family'] = 'Times New Roman'


ratios_and_errors_0p5N2 = np.flipud(np.loadtxt(r'..\data_upgraded\fig_8\258_263\ratiolist_258_263.txt',
                                     delimiter='\t', usecols=(1, 2), skiprows=1))
ratios_and_errors_1N2   = np.flipud(np.loadtxt(r'..\data_upgraded\fig_8\264_269\ratiolist_264_269.txt',
                                     delimiter='\t', usecols=(1, 2), skiprows=1))
ratios_and_errors_2N2   = np.flipud(np.loadtxt(r'..\data_upgraded\fig_8\270_275\ratiolist_270_275.txt',
                                     delimiter='\t', usecols=(1, 2), skiprows=1))


xticklist = np.array([-28.25, -22.95, -17.65, -12.35, -7.05, -1.75])
xticklist2 = xticklist-0.5
xticklist3 = xticklist+0.5


plt.figure(dpi=200)
plt.errorbar(xticklist2, ratios_and_errors_0p5N2[:,0], yerr=ratios_and_errors_0p5N2[:,1],
             linestyle='none', marker='s', elinewidth=1.0, capsize=3, label='1000 : 0.5')
plt.errorbar(xticklist , ratios_and_errors_1N2[:,0], yerr=ratios_and_errors_1N2[:,1],
             linestyle='none', marker='D', elinewidth=1.0, capsize=3, label='1000 : 1')
plt.errorbar(xticklist3, ratios_and_errors_2N2[:,0], yerr=ratios_and_errors_2N2[:,1],
             linestyle='none', marker='P', elinewidth=1.0, capsize=3, label='1000 : 2')


plt.grid(True, color='gray', linestyle='-', linewidth=0.1)

plt.ylim([0.45, 0.825])
plt.xticks([-28.25, -22.95, -17.65, -12.35, -7.05, -1.75])
plt.tick_params(axis='both', which='major', labelsize=13)

plt.xlabel('z-position / mm', size=15)
plt.ylabel('ratio of Penning- to \u03A9-peak\nbased on experimental data', size=15)
plt.legend(title='He : N$_\mathregular{2}$ flow / sccm',
           ncols = 3, columnspacing = 1, handletextpad=0, handlelength=1.5,
           loc='center', title_fontsize=12, fontsize=12, bbox_to_anchor=(0.5, 1.1))
plt.gca().set_aspect(80)



xpos_note = -0.875
ypos_note = 0.47

if 0:
    plt.savefig(r'..\figures' + '\\fig_8_ratios_experiment.png', dpi=200, bbox_inches='tight')
    plt.savefig(r'..\figures' + '\\fig_8_ratios_experiment.eps', dpi=200, bbox_inches='tight')

plt.show()
plt.close()
