# -*- coding: utf-8 -*-
'''
Author: David A. Schulenberg
Email: schulenberg@aept.rub.de

This script is part of the research paper "Mode transition induced by gas heating along
the discharge channel in capacitively coupled atmospheric pressure micro plasma jets"

This script is licensed under the MIT License.
See the file "LICENSE.txt" for the full license text.
'''

import os
import shutil

def findfilepaths(search_path, in_filename, not_in_filename, printpath):
    filepaths = []
    for root, dirs, files in os.walk(search_path):
        for name in files:
            file_path = os.path.join(root, name)
            if in_filename in file_path and not_in_filename not in file_path:
                if printpath: print(file_path)
                filepaths.append(file_path)
    return filepaths


def copylistoffiles(filepaths, destination, print_info):
    try:
        os.makedirs(destination, exist_ok=True)
    except:
        if print_info: print('Error occurred while creating destination directory.')
       
    for source in filepaths:
        try:
            shutil.copy(source, destination)
            if print_info: print('File copied successfully.')
        except shutil.SameFileError:
            if print_info: print('Source and destination represents the same file.')
        except PermissionError:
            if print_info: print('Permission denied, file not copied.')
        except:
            if print_info: print('Error occurred while copying file.')
            
        
def scriptcopy(scriptpath, destinationpath):
    # Get the current file name and directory path
    script_name = os.path.basename(scriptpath)
    dir_path = os.path.dirname(scriptpath)
    
    # Define the new file name and path
    new_script_name = os.path.splitext(script_name)[0] + '_localcopy' + os.path.splitext(script_name)[1]
    new_dir_path = destinationpath
    
    # Create the new directory if it doesn't exist
    if not os.path.exists(new_dir_path):
        os.makedirs(new_dir_path)
    
    # Copy the script to the new location with the new name
    shutil.copy2(os.path.join(dir_path, script_name), os.path.join(new_dir_path, new_script_name))
