# -*- coding: utf-8 -*-
'''
Author: David A. Schulenberg
Email: schulenberg@aept.rub.de

This script is part of the research paper "Mode transition induced by gas heating along
the discharge channel in capacitively coupled atmospheric pressure micro plasma jets"

This script is licensed under the MIT License.
See the file "LICENSE.txt" for the full license text.
'''

def estimate_tgas_increase(power_density):
    cmm_power = power_density * 1E-9 #J/s
    
    He_spec_density = 0.1785 #kg/m³
    He_heat_capacity  = 5193 #J/(kg K)
    
    cmm_He_mass = He_spec_density * 0.000000001 * 1 #kg/m³ * m³/mm³ * mm³ = kg
    
    He_heating_energy_demand = He_heat_capacity * cmm_He_mass #J/K
    
    # 1mm³ of He heated with 1mW of power has a temp increase of this per second:
    cmm_He_heating_speed = cmm_power / He_heating_energy_demand #(J/s)/(J/K) = K/s
    
    
    #How long does 1mm³ of He stay in the jet at a flow of 1000 sccm?
    He_flow_sccm = 1000 #cm³/min
    He_flow_cmm_p_s = (He_flow_sccm * 1000) / 60 #mm³/s
    
    #imagine a 1*1*x mm cube of He, this goes through the jet in 1s, therefor:
    He_flow_speed = He_flow_cmm_p_s / 1000 #m/s
    
    jet_lenght = 0.03 #m
    cmm_time_in_jet = jet_lenght / He_flow_speed #m/(m/s)
    
    final_temp_increase = cmm_He_heating_speed * cmm_time_in_jet #K/s * s = K
    
    return final_temp_increase


#power_density = 1000000 #J/(s m³)
#simulated_volume = 0.000000001 #m³ ==> 1mm³

#increase = estimate_tgas_increase(power_density, simulated_volume)
#print('Temperature increase along the jet:')
#print(str(increase)+' K')