# -*- coding: utf-8 -*-
'''
Author: David A. Schulenberg
Email: schulenberg@aept.rub.de

This script is part of the research paper "Mode transition induced by gas heating along
the discharge channel in capacitively coupled atmospheric pressure micro plasma jets"

This script is licensed under the MIT License.
See the file "LICENSE.txt" for the full license text.
'''

import numpy as np
import matplotlib.pyplot as plt
import numpy.polynomial.polynomial as poly
from scipy import integrate

import filehandling as fh

plt.rcParams['font.family'] = 'Times New Roman'


def linear_function(point1, point2, x_interval):
    (x1, y1), (x2, y2) = point1, point2
    m = (y2 - y1) / (x2 - x1)
    b = y1 - m * x1
    return m * x_interval + b


setnumbers = np.array([15, 16, 17, 18, 19, 20, 22, 23, 24, 25, 26, 27, 29, 30, 31, 32, 33, 34])
intervals = np.array([[355.200,355.322],[355.332,355.473],[355.482,355.623]])#new

mean_spectra = []
for setnr in setnumbers:
    #folder = r'..\data_upgraded\sup_fig_3\measured_spectra\A4OESset'.join(['', '0'+str(setnr)])
    folder = r'..\data_upgraded\fig_3_prototype_2\measurements\spectra'.join(['', '0'+str(setnr)])
    spectra_files = fh.findfilepaths(folder, '.spa', '?', False)
    
    data = []
    for spectrum_file in spectra_files:
        #spectrum = np.loadtxt(spectrum_file)
        spectrum = np.genfromtxt(spectrum_file, skip_header=22500, max_rows=500)
        data.append(spectrum[:,1])
        
    data = np.array(data)
    spectrum_average = np.transpose(np.vstack((spectrum[:,0], np.mean(data, axis=0))))
    
    if 1:
        plt.plot(spectrum_average[:, 0], spectrum_average[:, 1])
        plt.title(setnr)
        plt.show()
        plt.close()
    mean_spectra.append(spectrum_average)

#sets_intervals_ratios = np.array([[1],[2],[3],[4],[5]])
sets_intervals_ratios = np.array([[1],[2],[3],[4]])
for i, spectrum in enumerate(mean_spectra):
    x5 = np.where(spectrum[:,0] > 354)[0][0]
    x6 = np.where(spectrum[:,0] < 358)[0][-1]
    peak_intensity = np.max(spectrum[x5:x6,1])
    
    intervals_ratios = np.array([setnumbers[i],setnumbers[i],setnumbers[i]])
    for interval in intervals:        
        x1 = np.where(spectrum[:,0] == interval[0])[0][0]
        x2 = np.where(spectrum[:,0] == interval[1])[0][0]+1
        
        interval_data = spectrum[x1:x2]
        
        correction_function = linear_function(interval_data[0], interval_data[-1], interval_data[:,0])
        
        interval_corrected = np.copy(interval_data)
        interval_corrected[:,1] -= correction_function
        
        if 1:
            plt.plot(interval_data[:,0], interval_data[:,1])
            plt.plot(interval_data[:,0], correction_function)
            plt.plot(interval_corrected[:,0], interval_corrected[:,1], marker='s')
            plt.title(interval)
            plt.show()
            plt.close()
 
        interval_integrated = integrate.trapezoid(interval_corrected[:,1], x=interval_corrected[:,0])
        delta_lambda = interval_data[-1,0] - interval_data[0,0]
        
        ratio = interval_integrated / (delta_lambda * peak_intensity)
        interval_ratio = np.array([[interval[0], interval[1], ratio]])
        intervals_ratios = np.vstack((intervals_ratios, interval_ratio))
    
    sets_intervals_ratios = np.hstack((sets_intervals_ratios, intervals_ratios[:]))

    mask = np.any(sets_intervals_ratios < 1, axis=0)
    temps_ratios = np.copy(sets_intervals_ratios)
    temps_ratios = temps_ratios[:, mask]


polycoefs = np.loadtxt(r'..\data_upgraded\fig_3_prototype_2\simulation\polycoefs.txt', skiprows=1)[:,2:]

sets_temps = np.copy(temps_ratios)
for i, setratios in enumerate(temps_ratios[1:,:]):
    sets_temps[i+1] = poly.polyval(setratios, polycoefs[i])

if 1:
    plt.plot(range(18), sets_temps[1,:])
    plt.plot(range(18), sets_temps[2,:])
    plt.plot(range(18), sets_temps[3,:])
    plt.show()
    plt.close()
        
if 1:
    plt.plot([1,2,3,4,5,6], sets_temps[1,:6])
    plt.show()
    plt.close()

if 1:
    plt.plot([1,2,3,4,5,6], sets_temps[1,6:12])
    plt.show()
    plt.close()
    
if 1:
    plt.plot([1,2,3,4,5,6], sets_temps[1,12:18])
    plt.show()
    plt.close()
