# -*- coding: utf-8 -*-
'''
Author: David A. Schulenberg
Email: schulenberg@aept.rub.de

This script is part of the research paper "Mode transition induced by gas heating along
the discharge channel in capacitively coupled atmospheric pressure micro plasma jets"

This script is licensed under the MIT License.
See the file "LICENSE.txt" for the full license text.
'''


import numpy as np
import matplotlib.pyplot as plt
import numpy.polynomial.polynomial as poly
from scipy import integrate

import filehandling as fh

plt.rcParams['font.family'] = 'Times New Roman'


def linear_function(point1, point2, x_interval):
    (x1, y1), (x2, y2) = point1, point2
    m = (y2 - y1) / (x2 - x1)
    b = y1 - m * x1
    return m * x_interval + b



spectra_paths = fh.findfilepaths(r'..\data_upgraded\spectra', 'trot_', '?', False)
spectra_temperatures = [s[-7:-4] for s in spectra_paths]


intervals = np.array([[355.175,355.326],[355.335,355.476],[355.476,355.626]])
temps_intervals_ratios = np.array([[1],[2],[3],[4]])


for path in spectra_paths:
    spectrum = np.loadtxt(path)
    peak_intensity = np.max(spectrum)
    spectrum_temperature = int(path[-7:-4])
    if 1:
        plt.plot(spectrum[-400:-100, 0], spectrum[-400:-100, 1])
        plt.title(path[-10:])
        plt.show()
        plt.close()
        
    #intervals_ratios = np.array([['sim','temp', spectrum_temperature],['x1','x2','ratio']])
    intervals_ratios = np.array([spectrum_temperature,spectrum_temperature,spectrum_temperature])
    #break
    for interval in intervals:        
        x1 = np.where(spectrum[:,0] == interval[0])[0][0]
        x2 = np.where(spectrum[:,0] == interval[1])[0][0]+1
        interval_data = spectrum[x1:x2]
        
        correction_function = linear_function(interval_data[0], interval_data[-1], interval_data[:,0])
        
        interval_corrected = np.copy(interval_data)
        interval_corrected[:,1] -= correction_function
        
        if 1:
            plt.plot(interval_data[:,0], interval_data[:,1])
            plt.plot(interval_data[:,0], correction_function)
            plt.plot(interval_corrected[:,0], interval_corrected[:,1])
            plt.title(path[-10:]+', '+str(interval))
            plt.show()
            plt.close()
            

        interval_integrated = integrate.trapezoid(interval_corrected[:,1], x=interval_corrected[:,0])
        delta_lambda = interval_data[-1,0] - interval_data[0,0]
        
        ratio = interval_integrated / (delta_lambda * peak_intensity)
        interval_ratio = np.array([[interval[0], interval[1], ratio]])
        intervals_ratios = np.vstack((intervals_ratios, interval_ratio))
    
    temps_intervals_ratios = np.hstack((temps_intervals_ratios, intervals_ratios[:]))
    #break
    
    mask = np.any(temps_intervals_ratios < 1, axis=0)
    temps_ratios = np.copy(temps_intervals_ratios)
    temps_ratios = temps_ratios[:, mask]


interval_polycoefs = []
for i, interval in enumerate(intervals):
    polycoefs = poly.polyfit(temps_ratios[i+1,:], temps_ratios[0,:], 3)
    combined_data = np.hstack((interval, polycoefs))
    interval_polycoefs.append(combined_data)
    
interval_polycoefs = np.array(interval_polycoefs)

if 1:
    plt.plot(temps_ratios[1,:], temps_ratios[0,:], marker='s')
    plt.plot(temps_ratios[1,:], poly.polyval(temps_ratios[1,:], interval_polycoefs[0,2:]), color='black')
    plt.show()
    plt.close()


if 0:
    filename = r'..\data_upgraded\fig_3_prototype_2\simulation\polycoefs.txt'
    np.savetxt(filename, interval_polycoefs)


    with open(filename, 'r+') as f:
        content = f.read()
        f.seek(0, 0)
        f.write('interval1 interval2 coefficient0 coefficient1 coefficien2 coefficient3\n' + content)



